@@ -56,10 +56,10 @@ setConstructorS3("Package", function(name=NULL) {
 
   extend(Object(), "Package",
     .name = name,
+    .version = version,
     .libPath = libPath,
     .inBundle = NULL,
-    .bundlePackages = NULL,
-    .version = version
+    .bundlePackages = NULL
   )
 })
 
@@ -776,8 +776,7 @@ setMethodS3("load", "Package", function(this, ...) {
 setMethodS3("unload", "Package", function(this, ...) {
   name <- paste("package:", getName(this), sep="");
   pos <- which(name == search());
-  if (length(pos) == 1)
-    detach(pos=pos);
+  if (length(pos) == 1L) detach(pos=pos);
 })
 
 
@@ -1493,6 +1492,42 @@ setMethodS3("showHowToCite", "Package", function(this, ...) {
 
 
 
+#########################################################################/**
+# @RdocMethod startupMessage
+#
+# @title "Generates a 'package successfully loaded' package startup message"
+#
+# \description{
+#   @get "title".
+# }
+#
+# @synopsis
+#
+# \arguments{
+#   \item{...}{Additional arguments passed to 
+#              @see "base::packageStartupMessage".}
+# }
+#
+# \value{
+#   Returns nothing.
+# }
+#
+# @author
+#
+# \seealso{
+#   @see "base::packageStartupMessage".
+#
+#   @seeclass
+# }
+#*/#########################################################################
+setMethodS3("startupMessage", "Package", function(this, ...) {
+  msg <- sprintf("%s v%s (%s) successfully loaded. See ?%s for help.",
+       getName(this), getVersion(this), getDate(this), getName(this));
+  packageStartupMessage(msg, ...);
+}, protected=TRUE)
+
+
+
 #########################################################################/**
 # @RdocMethod update
 #
@@ -1611,8 +1646,11 @@ setMethodS3("update", "Package", function(object, contribUrl=c(getContribUrl(thi
   invisible(updated);
 })
 
+
 ############################################################################
 # HISTORY:
+# 2012-12-19
+# o Added startupMessage() for Package.
 # 2012-09-10
 # o BUG FIX: getContribUrl() and getDevelUrl() would give an error if
 #   corresponding fields did not exists in the DESCRIPTION file.  Now
